@@ -16,13 +16,13 @@ def parse(docpath):
     for tag in soup.body.find_all('a'):
         path = tag.get('href')
         if path and not path.startswith('#'):
-            name = tag.string.rsplit('.')[-1]
+            name = tag.string
             yield name, _guess_type(name, path), path
 
 
 def _guess_type(name, path):
     """Employ voodoo magic to guess the type of *name* in *path*."""
-    if name[0].isupper() and '#' not in path:
+    if name.rsplit('.', 1)[-1][0].isupper() and '#' not in path:
         return CLASS
     elif name.islower() and '#' not in path:
         return PACKAGE
